SocketOptionValue

Struct SocketOptionValue 

pub struct SocketOptionValue<'a>(/* private fields */);
Available on crate features net or virtio-vsock only.

Implementations

Source

impl SocketOptionValue<'_>

pub unsafe fn new(optval: *const c_void, optlen: socklen_t) -> Self

Creates a new socket option value from a raw pointer and its size

Safety
  • optval must be a null ptr, or a valid pointer provided to a setsockopt system call
  • optlen must be the data length of the optval ptr, as provided to a setsockopt system call