pub struct SocketOptionValue<'a>(/* private fields */);Available on crate features
net or virtio-vsock only.Implementations
Sourceimpl SocketOptionValue<'_>
impl SocketOptionValue<'_>
Sourcepub unsafe fn new(optval: *const c_void, optlen: socklen_t) -> Self
pub unsafe fn new(optval: *const c_void, optlen: socklen_t) -> Self
Creates a new socket option value from a raw pointer and its size
Safety
optvalmust be a null ptr, or a valid pointer provided to asetsockoptsystem calloptlenmust be the data length of theoptvalptr, as provided to asetsockoptsystem call